@@ -67,7 +67,8 @@ pub struct AsyncScramServer<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>>
 impl<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>> AsyncScramServer<'ss, S, A>
 {
     /// Returns the supported types in format SCRAM SCRAM SCRAM
-    pub fn advertise_types() -> String
+    pub 
+    fn advertise_types() -> String
     {
         return ScramCommon::adrvertise(" ");
     }
@@ -93,19 +94,25 @@ impl<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>> AsyncScramServer<'ss, S,
     /// let scramtype = ScramCommon::get_scramtype("SCRAM-SHA-256").unwrap();
     /// let scram_res = AsyncScramServer::<ScramSha256, AuthServer>::new(&serv, None, nonce, scramtype);
     /// ```
-    pub fn new(scram_auth_serv: &'ss A,
-                data_chanbind: Option<Vec<u8>>, 
-                scram_nonce: ScramNonce, 
-                st: &'ss ScramType) -> ScramResult<AsyncScramServer<'ss, S, A>>
+    pub 
+    fn new(
+        scram_auth_serv: &'ss A,
+        data_chanbind: Option<Vec<u8>>, 
+        scram_nonce: ScramNonce, 
+        st: &'ss ScramType
+    ) -> ScramResult<AsyncScramServer<'ss, S, A>>
     {
         if st.scram_chan_bind == true && data_chanbind.is_none() == true
         {
-            scram_error!(ScramErrorCode::ExternalError,
-                        "scram: '{}' requires the data_chanbind to be set",
-                        st);
+            scram_error!(
+                ScramErrorCode::ExternalError,
+                "scram: '{}' requires the data_chanbind to be set",
+                st
+            );
         }
 
-        let res = Self
+        let res = 
+            Self
             {
                 hasher: PhantomData,
                 auth: scram_auth_serv,
@@ -130,18 +137,29 @@ impl<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>> AsyncScramServer<'ss, S,
     /// # Returns
     /// 
     /// * ScramResult<[ScramParse]> the response will be encoded to UTF-8
-    pub async fn parse_response_base64<T>(&mut self, input: T) -> ScramResult<ScramParse>
+    pub async 
+    fn parse_response_base64<T>(&mut self, input: T) -> ScramResult<ScramParse>
     where T: AsRef<[u8]>
     {
         let decoded = 
             base64::decode(input)
-                .map_err(|e| scram_error_map!(ScramErrorCode::MalformedScramMsg, 
-                                            "base64 decode client response failed, '{}'", e))?;
+                .map_err(|e| 
+                    scram_error_map!(
+                        ScramErrorCode::MalformedScramMsg, 
+                        "base64 decode client response failed, '{}'", 
+                        e
+                    )
+                )?;
 
         let dec_utf8 = 
             str::from_utf8(&decoded)
-                .map_err(|e| scram_error_map!(ScramErrorCode::MalformedScramMsg, 
-                                            "base64 decoded response contains invalid UTF-8 seq, '{}'", e))?;
+                .map_err(|e| 
+                    scram_error_map!(
+                        ScramErrorCode::MalformedScramMsg, 
+                        "base64 decoded response contains invalid UTF-8 seq, '{}'", 
+                        e
+                    )
+                )?;
 
         return self.parse_response(dec_utf8, true).await;
     }
@@ -159,7 +177,8 @@ impl<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>> AsyncScramServer<'ss, S,
     /// 
     /// * ScramResult<[ScramParse]> the response will be encoded to UTF-8 depending on
     /// argument `to_base`
-    pub async fn parse_response(&mut self, resp: &str, to_base: bool) -> ScramResult<ScramParse>
+    pub async 
+    fn parse_response(&mut self, resp: &str, to_base: bool) -> ScramResult<ScramParse>
     {
         let parsed_resp = ScramDataParser::from_raw(resp, &self.state)?;
 
@@ -225,8 +244,11 @@ impl<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>> AsyncScramServer<'ss, S,
                 // verify nonce
                 if finalnonce != nonce.as_str()
                 {
-                    scram_error!(ScramErrorCode::VerificationError,
-                                "received invalid nonce rcvn: {} have: {}", finalnonce, client_nonce);
+                    scram_error!(
+                        ScramErrorCode::VerificationError,
+                        "received invalid nonce rcvn: {} have: {}", 
+                        finalnonce, client_nonce
+                    );
                 }
 
                 /*let cb_data = base64::encode(
@@ -240,11 +262,11 @@ impl<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>> AsyncScramServer<'ss, S,
                 let client_final_without_proof = ["c=", chanbinding, ",r=", &nonce].concat();
                 let client_first_bare = ["n=", self.username.as_ref().unwrap(), ",r=", client_nonce].concat();
                 let server_first = 
-                            [
-                                "r=", &nonce, 
-                                ",s=", self.sp.get_salt_base64(),
-                                ",i=", &self.sp.get_iterations().to_string(),
-                            ].concat();
+                    [
+                        "r=", &nonce, 
+                        ",s=", self.sp.get_salt_base64(),
+                        ",i=", &self.sp.get_iterations().to_string(),
+                    ].concat();
 
                 let authmsg = 
                     [
@@ -266,13 +288,18 @@ impl<'ss, S: ScramHashing, A: AsyncScramAuthServer<S>> AsyncScramServer<'ss, S,
 
                 // verify proof
                 let recv_decoded_proof = 
-                                base64::decode(proof)
-                                        .map_err(|e| scram_error_map!(ScramErrorCode::MalformedScramMsg, 
-                                                                     "base64 decode client proof failed, {}", e))?;
+                    base64::decode(proof)
+                        .map_err(|e| 
+                            scram_error_map!(
+                                ScramErrorCode::MalformedScramMsg, 
+                                "base64 decode client proof failed, {}", 
+                                e
+                            )
+                        )?;
+
                 if calc_client_proof != recv_decoded_proof
                 {
-                    scram_error!(ScramErrorCode::VerificationError,
-                                "received invalid proof from client");
+                    scram_error!(ScramErrorCode::VerificationError, "received invalid proof from client");
                 }
 
                 let output = 
@@ -348,30 +375,35 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
     ///
     /// let scram_res = AsyncScramClient::<ScramSha256, AuthClient>::new(&ac, nonce, cbt);
     /// ```
-    pub fn new(scram_auth_cli: &'sc A, 
-                scram_nonce: ScramNonce, 
-                chan_bind_type: ClientChannelBindingType) -> ScramResult<AsyncScramClient<'sc, S, A>>
+    pub 
+    fn new(
+        scram_auth_cli: &'sc A, 
+        scram_nonce: ScramNonce, 
+        chan_bind_type: ClientChannelBindingType
+    ) -> ScramResult<AsyncScramClient<'sc, S, A>>
     {
         return Ok(
-                    Self
-                        {
-                            hasher: PhantomData,
-                            auth: scram_auth_cli,
-                            client_nonce: scram_nonce.get_nonce()?,
-                            state: ScramState::InitClient,
-                            chanbind: chan_bind_type,
-                        }
-                );
+            Self
+            {
+                hasher: PhantomData,
+                auth: scram_auth_cli,
+                client_nonce: scram_nonce.get_nonce()?,
+                state: ScramState::InitClient,
+                chanbind: chan_bind_type,
+            }
+        );
     }
 
     /// Checks if the client authentification was completed successfully.
-    pub fn is_completed(&self) -> bool
+    pub 
+    fn is_completed(&self) -> bool
     {
-        match self.state
+        return self.state == ScramState::Completed;
+        /*match self.state
         {
             ScramState::Completed => return true,
             _ => return false,
-        }
+        }*/
     }
 
     /// Initializes the SCRAM negoatiation from client
@@ -383,11 +415,15 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
     /// 
     /// # Returns
     /// * base64 encoded or plain string with formed message
-    pub async fn init_client(&mut self, to_base64: bool) -> String
+    pub async 
+    fn init_client(&mut self, to_base64: bool) -> String
     {            
-        let compiled = [self.chanbind.convert2header(),
-                        b"n=", self.auth.get_username().await.as_bytes(),
-                        b",r=", &self.client_nonce.as_bytes()].concat();
+        let compiled = 
+            [
+                self.chanbind.convert2header(),
+                b"n=", self.auth.get_username().await.as_bytes(),
+                b",r=", &self.client_nonce.as_bytes()
+            ].concat();
         
         self.state = ScramState::WaitForServInitMsg;     
         
@@ -397,7 +433,7 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
         }
         else
         {
-            return unsafe {String::from_utf8_unchecked(compiled)};
+            return unsafe { String::from_utf8_unchecked(compiled) };
         }
     }
 
@@ -411,17 +447,28 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
     /// # Returns
     /// 
     /// * ScramResult<[ScramParse]> the response will be encoded to UTF-8 
-    pub async fn parse_response_base64<T: AsRef<[u8]>>(&mut self, input: T) -> ScramResult<ScramParse>
+    pub async 
+    fn parse_response_base64<T: AsRef<[u8]>>(&mut self, input: T) -> ScramResult<ScramParse>
     {
         let decoded = 
             base64::decode(input)
-                .map_err(|e| scram_error_map!(ScramErrorCode::MalformedScramMsg, 
-                                            "base64 decode server response failed, '{}'", e))?;
+                .map_err(|e| 
+                    scram_error_map!(
+                        ScramErrorCode::MalformedScramMsg, 
+                        "base64 decode server response failed, '{}'", 
+                        e
+                    )
+                )?;
 
         let dec_utf8 = 
             str::from_utf8(&decoded)
-                .map_err(|e| scram_error_map!(ScramErrorCode::MalformedScramMsg, 
-                                            "base64 decoded response contains invalid UTF-8 seq, '{}'", e))?;
+                .map_err(|e| 
+                    scram_error_map!(
+                        ScramErrorCode::MalformedScramMsg, 
+                        "base64 decoded response contains invalid UTF-8 seq, '{}'", 
+                        e
+                    )
+                )?;
 
         return self.parse_response(dec_utf8, true).await;
     }
@@ -439,7 +486,8 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
     /// 
     /// * ScramResult<[ScramParse]> the response will be encoded to UTF-8 depending on
     /// argument `to_base64`
-    pub async fn parse_response(&mut self, resp: &str, to_base64: bool) -> ScramResult<ScramParse>
+    pub async 
+    fn parse_response(&mut self, resp: &str, to_base64: bool) -> ScramResult<ScramParse>
     {
         let parsed_resp = ScramDataParser::from_raw(&resp, &self.state)?;
 
@@ -455,26 +503,31 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
                 //validate iterations
                 if itrcnt == 0 || itrcnt > 999999999
                 {
-                    scram_error!(ScramErrorCode::InternalError, 
-                                "iterations count is not appropriate: i='{}'", itrcnt);
+                    scram_error!(
+                        ScramErrorCode::InternalError, 
+                        "iterations count is not appropriate: i='{}'", 
+                        itrcnt
+                    );
                 }
 
                 //todo channel bind things SASL 
-                let cb_data = base64::encode(
-                                [
-                                    self.chanbind.convert2header(), 
-                                    self.chanbind.convert2data()
-                                ].concat());
+                let cb_data = 
+                    base64::encode(
+                        [
+                            self.chanbind.convert2header(), 
+                            self.chanbind.convert2data()
+                        ].concat()
+                    );
 
                 let client_final_message_bare = ["c=", &cb_data, ",r=", nonce].concat();
 
                 let authmsg = 
-                            [
-                                b"n=", self.auth.get_username().await.as_bytes(),
-                                b",r=", self.client_nonce.as_bytes(), 
-                                b",", resp.as_bytes(),
-                                b",", client_final_message_bare.as_bytes()
-                            ].concat();
+                    [
+                        b"n=", self.auth.get_username().await.as_bytes(),
+                        b",r=", self.client_nonce.as_bytes(), 
+                        b",", resp.as_bytes(),
+                        b",", client_final_message_bare.as_bytes()
+                    ].concat();
 
                 let salted_password = 
                     S::derive(self.auth.get_password().await.as_bytes(), &salt, itrcnt)?;
@@ -488,11 +541,12 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
                 let client_signature = S::hmac(&authmsg, &stored_key)?;
                 let server_signature = S::hmac(&authmsg, &server_key)?;
                 
-                let client_response = [
-                                        &client_final_message_bare,
-                                        ",p=",
-                                        &base64::encode(ScramDataParser::xor_arrays(&client_key, &client_signature)?)
-                                    ].concat();
+                let client_response = 
+                    [
+                        &client_final_message_bare,
+                        ",p=",
+                        &base64::encode(ScramDataParser::xor_arrays(&client_key, &client_signature)?)
+                    ].concat();
                 
 
                 self.state = ScramState::WaitForServFinalMsg{server_signature: server_signature};
@@ -521,10 +575,11 @@ impl<'sc, S: ScramHashing, A: AsyncScramAuthClient> AsyncScramClient<'sc, S, A>
                 }
                 else
                 {
-                    scram_error!(ScramErrorCode::VerificationError,
-                                "state: '{}', server signature mismatch, \
-                                server sig: '{:x?}', local: {:x?}",
-                                self.state, server_verifier, verifier);
+                    scram_error!(
+                        ScramErrorCode::VerificationError,
+                        "state: '{}', server signature mismatch, server sig: '{:x?}', local: {:x?}",
+                        self.state, server_verifier, verifier
+                    );
                 }
 
             }
@@ -642,12 +697,12 @@ fn scram_sha256_works()
     #[async_trait]
     impl AsyncScramAuthClient for AuthClient
     {
-        async fn get_username(&self) -> &String
+        async fn get_username(&self) -> &str
         {
             return &self.username;
         }
 
-        async fn get_password(&self) -> &String
+        async fn get_password(&self) -> &str
         {
             return &self.password;
         }
